@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2026, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -438,14 +438,7 @@ public class FormatData_az extends ListResourceBundle {
             { "japanese.abbreviated.AmPmMarkers", metaValue_generic_abbreviated_AmPmMarkers },
             { "japanese.TimePatterns", metaValue_generic_TimePatterns },
             { "java.time.japanese.DatePatterns", metaValue_java_time_generic_DatePatterns },
-            { "japanese.DatePatterns",
-                new String[] {
-                    "GGGG d MMMM yyyy, EEEE",
-                    "GGGG d MMMM, yyyy",
-                    "GGGG d MMM y",
-                    "G dd.MM.y",
-                }
-            },
+            { "japanese.DatePatterns", metaValue_generic_DatePatterns },
             { "japanese.DateFormatItem.hm", metaValue_generic_DateFormatItem_hm },
             { "japanese.DateFormatItem.yMMMEd", metaValue_generic_DateFormatItem_yMMMEd },
             { "japanese.DateFormatItem.Ehms", metaValue_generic_DateFormatItem_Ehms },
